@@ -4,22 +4,7 @@
 
 @authors Andrei Novikov (pyclustering@yandex.ru)
 @date 2014-2020
-@copyright GNU Public License
-
-@cond GNU_PUBLIC_LICENSE
-    PyClustering is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-    
-    PyClustering is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-@endcond
+@copyright BSD-3-Clause
 
 """
 
@@ -33,7 +18,7 @@ matplotlib.use('Agg')
 from pyclustering.cluster.kmedoids import kmedoids
 from pyclustering.cluster.tests.kmedoids_templates import kmedoids_test_template
 
-from pyclustering.samples.definitions import SIMPLE_SAMPLES
+from pyclustering.samples.definitions import SIMPLE_SAMPLES, SIMPLE_ANSWERS
 
 from pyclustering.utils import read_sample
 from pyclustering.utils.metric import type_metric, distance_metric
@@ -248,7 +233,7 @@ class KmedoidsUnitTest(unittest.TestCase):
 
     def testAllocatedRequestedClustersWithTheSamePoints(self):
         # Bug issue #366 - Kmedoids returns incorrect number of clusters.
-        sample = [ [0.0, 0.0], [0.1, 0.1], [0.0, 0.0], [0.1, 0.2] ]
+        sample = [[0.0, 0.0], [0.1, 0.1], [0.0, 0.0], [0.1, 0.2]]
         kmedoids_test_template.templateAllocateRequestedClusterAmount(sample, 4, None, False)
         kmedoids_test_template.templateAllocateRequestedClusterAmount(sample, 3, None, False)
         kmedoids_test_template.templateAllocateRequestedClusterAmount(sample, 2, None, False)
@@ -257,7 +242,7 @@ class KmedoidsUnitTest(unittest.TestCase):
 
     def testAllocatedRequestedClustersWithTotallyTheSamePoints(self):
         # Bug issue #366 - Kmedoids returns incorrect number of clusters.
-        sample = [ [0.0, 0.0], [0.0, 0.0], [0.0, 0.0], [0.0, 0.0] ]
+        sample = [[0.0, 0.0], [0.0, 0.0], [0.0, 0.0], [0.0, 0.0]]
         kmedoids_test_template.templateAllocateRequestedClusterAmount(sample, 4, None, False)
         kmedoids_test_template.templateAllocateRequestedClusterAmount(sample, 3, None, False)
         kmedoids_test_template.templateAllocateRequestedClusterAmount(sample, 2, None, False)
@@ -277,6 +262,46 @@ class KmedoidsUnitTest(unittest.TestCase):
         kmedoids_test_template.templateLengthProcessData(SIMPLE_SAMPLES.SAMPLE_SIMPLE2, [3, 12, 20], [10, 5, 8], False, itermax=10)
 
 
+    def testSimple01Answer(self):
+        kmedoids_test_template.clustering_with_answer(SIMPLE_SAMPLES.SAMPLE_SIMPLE1, SIMPLE_ANSWERS.ANSWER_SIMPLE1, False, random_state=1000)
+
+    def testSimple02Answer(self):
+        kmedoids_test_template.clustering_with_answer(SIMPLE_SAMPLES.SAMPLE_SIMPLE2, SIMPLE_ANSWERS.ANSWER_SIMPLE2, False, random_state=1000)
+
+    def testSimple03Answer(self):
+        kmedoids_test_template.clustering_with_answer(SIMPLE_SAMPLES.SAMPLE_SIMPLE3, SIMPLE_ANSWERS.ANSWER_SIMPLE3, False, random_state=1000)
+
+    def testSimple04Answer(self):
+        kmedoids_test_template.clustering_with_answer(SIMPLE_SAMPLES.SAMPLE_SIMPLE4, SIMPLE_ANSWERS.ANSWER_SIMPLE4, False, random_state=1000)
+
+    def testSimple05Answer(self):
+        kmedoids_test_template.clustering_with_answer(SIMPLE_SAMPLES.SAMPLE_SIMPLE5, SIMPLE_ANSWERS.ANSWER_SIMPLE5, False, random_state=1000)
+
+    def testSimple06Answer(self):
+        kmedoids_test_template.clustering_with_answer(SIMPLE_SAMPLES.SAMPLE_SIMPLE6, SIMPLE_ANSWERS.ANSWER_SIMPLE6, False, random_state=1000)
+
+    def testSimple07Answer(self):
+        kmedoids_test_template.clustering_with_answer(SIMPLE_SAMPLES.SAMPLE_SIMPLE7, SIMPLE_ANSWERS.ANSWER_SIMPLE7, False, random_state=1000)
+
+    def testSimple08Answer(self):
+        kmedoids_test_template.clustering_with_answer(SIMPLE_SAMPLES.SAMPLE_SIMPLE8, SIMPLE_ANSWERS.ANSWER_SIMPLE8, False, random_state=1000)
+
+    def testSimple09Answer(self):
+        kmedoids_test_template.clustering_with_answer(SIMPLE_SAMPLES.SAMPLE_SIMPLE9, SIMPLE_ANSWERS.ANSWER_SIMPLE9, False, random_state=1000)
+
+    def testSimple10Answer(self):
+        kmedoids_test_template.clustering_with_answer(SIMPLE_SAMPLES.SAMPLE_SIMPLE10, SIMPLE_ANSWERS.ANSWER_SIMPLE10, False, random_state=1000)
+
+    def testSimple11Answer(self):
+        kmedoids_test_template.clustering_with_answer(SIMPLE_SAMPLES.SAMPLE_SIMPLE11, SIMPLE_ANSWERS.ANSWER_SIMPLE11, False, random_state=1000)
+
+    def testSimple12Answer(self):
+        kmedoids_test_template.clustering_with_answer(SIMPLE_SAMPLES.SAMPLE_SIMPLE12, SIMPLE_ANSWERS.ANSWER_SIMPLE12, False, random_state=1000)
+
+    def testSimple13Answer(self):
+        kmedoids_test_template.clustering_with_answer(SIMPLE_SAMPLES.SAMPLE_SIMPLE13, SIMPLE_ANSWERS.ANSWER_SIMPLE13, False, random_state=1000)
+
+
     def test_incorrect_data(self):
         self.assertRaises(ValueError, kmedoids, [], [1])
 
